from __future__ import annotations

import json
from pathlib import Path
from typing import Dict

from .models import Color, ColorCombination

COLORS = [
    {
        "name": "Hermosa Pink",
        "cmyk": [0, 30, 6, 0],
        "combinations": [176, 227, 273],
        "rgbfloat": [255.0, 178.5, 239.7],
        "rgb": [255, 178, 239],
        "hex": "#ffb2ef",
        "index": 1,
    },
    {
        "name": "Corinthian Pink",
        "cmyk": [0, 35, 15, 0],
        "combinations": [
            27,
            43,
            87,
            97,
            128,
            169,
            174,
            206,
            246,
            254,
            264,
            342,
        ],
        "rgbfloat": [255.0, 165.75, 216.75],
        "rgb": [255, 165, 216],
        "hex": "#ffa5d8",
        "index": 2,
    },
    {
        "name": "Cameo Pink",
        "cmyk": [10, 32, 19, 0],
        "combinations": [18, 125, 308],
        "rgbfloat": [229.5, 173.39999999999998, 206.55],
        "rgb": [229, 173, 206],
        "hex": "#e5adce",
        "index": 3,
    },
    {
        "name": "Fawn",
        "cmyk": [18, 31, 30, 0],
        "combinations": [18, 125, 308],
        "rgbfloat": [209.10000000000002, 175.95, 178.5],
        "rgb": [209, 175, 178],
        "hex": "#d1afb2",
        "index": 4,
    },
    {
        "name": "Light Brown Drab",
        "cmyk": [8, 30, 20, 25],
        "combinations": [35, 68, 185, 191, 223, 239, 244, 268, 285, 321],
        "rgbfloat": [175.95000000000002, 133.875, 153.0],
        "rgb": [175, 133, 153],
        "hex": "#af8599",
        "index": 5,
    },
    {
        "name": "Coral Red",
        "cmyk": [0, 55, 40, 0],
        "combinations": [92, 123, 320, 332],
        "rgbfloat": [255.0, 114.74999999999999, 153.0],
        "rgb": [255, 114, 153],
        "hex": "#ff7299",
        "index": 6,
    },
    {
        "name": "Fresh Color",
        "cmyk": [0, 53, 45, 0],
        "combinations": [240],
        "rgbfloat": [255.0, 119.85, 140.25],
        "rgb": [255, 119, 140],
        "hex": "#ff778c",
        "index": 7,
    },
    {
        "name": "Grenadine Pink",
        "cmyk": [0, 62, 58, 0],
        "combinations": [6, 21, 112, 166, 193, 201, 230, 300, 315, 341],
        "rgbfloat": [255.0, 96.9, 107.10000000000001],
        "rgb": [255, 96, 107],
        "hex": "#ff606b",
        "index": 8,
    },
    {
        "name": "Eosine Pink",
        "cmyk": [0, 63, 23, 0],
        "combinations": [
            34,
            59,
            90,
            108,
            134,
            153,
            197,
            242,
            248,
            276,
            287,
            314,
            327,
            336,
        ],
        "rgbfloat": [255.0, 94.35, 196.35],
        "rgb": [255, 94, 196],
        "hex": "#ff5ec4",
        "index": 9,
    },
    {
        "name": "Spinel Red",
        "cmyk": [0, 70, 21, 0],
        "combinations": [14, 147, 165, 184, 195, 224, 277],
        "rgbfloat": [255.0, 76.50000000000001, 201.45000000000002],
        "rgb": [255, 76, 201],
        "hex": "#ff4cc9",
        "index": 10,
    },
    {
        "name": "Old Rose",
        "cmyk": [15, 70, 40, 0],
        "combinations": [55, 162, 260, 265],
        "rgbfloat": [216.75, 76.50000000000001, 153.0],
        "rgb": [216, 76, 153],
        "hex": "#d84c99",
        "index": 11,
    },
    {
        "name": "Eugenia Red | A",
        "cmyk": [7, 76, 60, 0],
        "combinations": [284],
        "rgbfloat": [237.14999999999998, 61.199999999999996, 102.0],
        "rgb": [237, 61, 102],
        "hex": "#ed3d66",
        "index": 12,
    },
    {
        "name": "Eugenia Red | B",
        "cmyk": [0, 80, 50, 10],
        "combinations": [17, 77, 252, 262, 270, 280, 282, 325],
        "rgbfloat": [229.5, 45.89999999999999, 114.75],
        "rgb": [229, 45, 114],
        "hex": "#e52d72",
        "index": 13,
    },
    {
        "name": "Raw Sienna",
        "cmyk": [18, 58, 100, 12],
        "combinations": [
            3,
            13,
            33,
            70,
            86,
            130,
            131,
            182,
            243,
            247,
            252,
            255,
            268,
            269,
            279,
            293,
            298,
            319,
            327,
        ],
        "rgbfloat": [184.008, 94.248, 0.0],
        "rgb": [184, 94, 0],
        "hex": "#b85e00",
        "index": 14,
    },
    {
        "name": "Vinaceous Tawny",
        "cmyk": [17, 72, 100, 6],
        "combinations": [40, 85, 244],
        "rgbfloat": [198.95099999999996, 67.116, 0.0],
        "rgb": [198, 67, 0],
        "hex": "#c64300",
        "index": 15,
    },
    {
        "name": "Jasper Red",
        "cmyk": [2, 83, 100, 0],
        "combinations": [155, 194, 216, 219],
        "rgbfloat": [249.9, 43.35000000000001, 0.0],
        "rgb": [249, 43, 0],
        "hex": "#f92b00",
        "index": 16,
    },
    {
        "name": "Spectrum Red",
        "cmyk": [5, 100, 100, 0],
        "combinations": [257, 266, 301, 322],
        "rgbfloat": [242.25, 0.0, 0.0],
        "rgb": [242, 0, 0],
        "hex": "#f20000",
        "index": 17,
    },
    {
        "name": "Red Orange",
        "cmyk": [9, 90, 100, 0],
        "combinations": [31, 164, 179, 241, 264],
        "rgbfloat": [232.05, 25.499999999999993, 0.0],
        "rgb": [232, 25, 0],
        "hex": "#e81900",
        "index": 18,
    },
    {
        "name": "Etruscan Red",
        "cmyk": [16, 80, 74, 6],
        "combinations": [25, 47, 97, 137, 152, 185, 275],
        "rgbfloat": [201.34799999999998, 47.93999999999998, 62.321999999999996],
        "rgb": [201, 47, 62],
        "hex": "#c92f3e",
        "index": 19,
    },
    {
        "name": "Burnt Sienna",
        "cmyk": [22, 76, 100, 15],
        "combinations": [198, 242, 263, 285, 286, 297, 312, 333, 343],
        "rgbfloat": [169.065, 52.019999999999996, 0.0],
        "rgb": [169, 52, 0],
        "hex": "#a93400",
        "index": 20,
    },
    {
        "name": "Ochre Red",
        "cmyk": [18, 73, 63, 20],
        "combinations": [199, 283],
        "rgbfloat": [167.28000000000003, 55.08000000000001, 75.48],
        "rgb": [167, 55, 75],
        "hex": "#a7374b",
        "index": 21,
    },
    {
        "name": "Scarlet",
        "cmyk": [10, 95, 72, 7],
        "combinations": [136, 308, 332],
        "rgbfloat": [213.43499999999997, 11.857500000000009, 66.402],
        "rgb": [213, 11, 66],
        "hex": "#d50b42",
        "index": 22,
    },
    {
        "name": "Carmine",
        "cmyk": [0, 100, 75, 16],
        "combinations": [39, 117, 122, 154, 225, 232, 307, 313],
        "rgbfloat": [214.2, 0.0, 53.55],
        "rgb": [214, 0, 53],
        "hex": "#d60035",
        "index": 23,
    },
    {
        "name": "Indian Lake",
        "cmyk": [12, 89, 35, 9],
        "combinations": [299, 331],
        "rgbfloat": [204.204, 25.525499999999997, 150.8325],
        "rgb": [204, 25, 150],
        "hex": "#cc1996",
        "index": 24,
    },
    {
        "name": "Rosolanc Purple",
        "cmyk": [30, 90, 33, 0],
        "combinations": [48, 144, 170, 204, 277],
        "rgbfloat": [178.5, 25.499999999999993, 170.85],
        "rgb": [178, 25, 170],
        "hex": "#b219aa",
        "index": 25,
    },
    {
        "name": "Pomegranite Purple",
        "cmyk": [23, 100, 50, 6],
        "combinations": [220, 271],
        "rgbfloat": [184.569, 0.0, 119.85],
        "rgb": [184, 0, 119],
        "hex": "#b80077",
        "index": 26,
    },
    {
        "name": "Hydrangea Red",
        "cmyk": [38, 90, 70, 0],
        "combinations": [142],
        "rgbfloat": [158.1, 25.499999999999993, 76.50000000000001],
        "rgb": [158, 25, 76],
        "hex": "#9e194c",
        "index": 27,
    },
    {
        "name": "Brick Red",
        "cmyk": [22, 84, 100, 18],
        "combinations": [37, 108, 246, 322, 328],
        "rgbfloat": [163.098, 33.45600000000001, 0.0],
        "rgb": [163, 33, 0],
        "hex": "#a32100",
        "index": 28,
    },
    {
        "name": "Carmine Red",
        "cmyk": [25, 95, 80, 16],
        "combinations": [35, 51, 104, 130, 181, 200, 221, 228, 233, 237, 245],
        "rgbfloat": [160.65, 10.710000000000008, 42.83999999999999],
        "rgb": [160, 10, 42],
        "hex": "#a00a2a",
        "index": 29,
    },
    {
        "name": "Pompeian Red",
        "cmyk": [18, 97, 74, 19],
        "combinations": [30, 71, 120, 212, 311, 324],
        "rgbfloat": [169.37100000000004, 6.196500000000006, 53.703],
        "rgb": [169, 6, 53],
        "hex": "#a90635",
        "index": 30,
    },
    {
        "name": "Red",
        "cmyk": [30, 100, 70, 10],
        "combinations": [251, 261],
        "rgbfloat": [160.65, 0.0, 68.85000000000001],
        "rgb": [160, 0, 68],
        "hex": "#a00044",
        "index": 31,
    },
    {
        "name": "Brown",
        "cmyk": [35, 74, 90, 35],
        "combinations": [110, 121, 145, 161],
        "rgbfloat": [107.7375, 43.095, 16.574999999999996],
        "rgb": [107, 43, 16],
        "hex": "#6b2b10",
        "index": 32,
    },
    {
        "name": "Hay's Russet",
        "cmyk": [37, 85, 87, 35],
        "combinations": [58, 82, 95, 152, 186, 231, 249, 304, 314, 336, 345],
        "rgbfloat": [104.42250000000001, 24.862500000000004, 21.5475],
        "rgb": [104, 24, 21],
        "hex": "#681815",
        "index": 33,
    },
    {
        "name": "Vandyke Red",
        "cmyk": [32, 95, 95, 33],
        "combinations": [16, 133, 147, 316, 335],
        "rgbfloat": [116.17799999999997, 8.542500000000006, 8.542500000000006],
        "rgb": [116, 8, 8],
        "hex": "#740808",
        "index": 34,
    },
    {
        "name": "Pansy Purple",
        "cmyk": [34, 100, 60, 34],
        "combinations": [157, 273],
        "rgbfloat": [111.07799999999997, 0.0, 67.32],
        "rgb": [111, 0, 67],
        "hex": "#6f0043",
        "index": 35,
    },
    {
        "name": "Pale Burnt Lake",
        "cmyk": [25, 90, 80, 40],
        "combinations": [124, 171, 177, 205, 217, 258, 269, 283],
        "rgbfloat": [114.75, 15.299999999999995, 30.59999999999999],
        "rgb": [114, 15, 30],
        "hex": "#720f1e",
        "index": 36,
    },
    {
        "name": "Violet Red",
        "cmyk": [75, 100, 50, 5],
        "combinations": [9],
        "rgbfloat": [60.5625, 0.0, 121.125],
        "rgb": [60, 0, 121],
        "hex": "#3c0079",
        "index": 37,
    },
    {
        "name": "Vistoris Lake",
        "cmyk": [40, 71, 55, 40],
        "combinations": [63, 91, 165, 226, 290, 337],
        "rgbfloat": [91.8, 44.37, 68.85],
        "rgb": [91, 44, 68],
        "hex": "#5b2c44",
        "index": 38,
    },
    {
        "name": "Sulpher Yellow",
        "cmyk": [4, 4, 28, 0],
        "combinations": [
            52,
            72,
            80,
            104,
            132,
            135,
            151,
            208,
            246,
            254,
            270,
            294,
            296,
            310,
            315,
            320,
            321,
            326,
        ],
        "rgbfloat": [244.79999999999998, 244.79999999999998, 183.6],
        "rgb": [244, 244, 183],
        "hex": "#f4f4b7",
        "index": 39,
    },
    {
        "name": "Pale Lemon Yellow",
        "cmyk": [0, 4, 38, 0],
        "combinations": [
            3,
            31,
            60,
            76,
            99,
            109,
            111,
            169,
            185,
            195,
            203,
            228,
            241,
            261,
            272,
            281,
            290,
            292,
            336,
        ],
        "rgbfloat": [255.0, 244.79999999999998, 158.1],
        "rgb": [255, 244, 158],
        "hex": "#fff49e",
        "index": 40,
    },
    {
        "name": "Naples Yellow",
        "cmyk": [2, 7, 44, 0],
        "combinations": [14, 115, 166, 193, 303, 325],
        "rgbfloat": [249.9, 237.14999999999998, 142.8],
        "rgb": [249, 237, 142],
        "hex": "#f9ed8e",
        "index": 41,
    },
    {
        "name": "Ivory Buff",
        "cmyk": [8, 15, 40, 0],
        "combinations": [
            11,
            50,
            94,
            102,
            126,
            178,
            184,
            190,
            209,
            214,
            235,
            243,
            262,
            266,
            301,
            343,
        ],
        "rgbfloat": [234.60000000000002, 216.75, 153.0],
        "rgb": [234, 216, 153],
        "hex": "#ead899",
        "index": 42,
    },
    {
        "name": "Seashell Pink",
        "cmyk": [0, 19, 23, 0],
        "combinations": [45, 84, 88, 113, 150, 176, 194, 276, 334],
        "rgbfloat": [255.0, 206.55, 196.35],
        "rgb": [255, 206, 196],
        "hex": "#ffcec4",
        "index": 43,
    },
    {
        "name": "Light Pinkish Cinnamon",
        "cmyk": [0, 25, 40, 0],
        "combinations": [317],
        "rgbfloat": [255.0, 191.25, 153.0],
        "rgb": [255, 191, 153],
        "hex": "#ffbf99",
        "index": 44,
    },
    {
        "name": "Pinkish Cinnamon",
        "cmyk": [5, 32, 53, 0],
        "combinations": [78, 175, 232, 258, 263, 292, 305, 310],
        "rgbfloat": [242.25, 173.39999999999998, 119.85],
        "rgb": [242, 173, 119],
        "hex": "#f2ad77",
        "index": 45,
    },
    {
        "name": "Cinnamon Buff",
        "cmyk": [0, 25, 57, 0],
        "combinations": [23, 127, 137, 180, 210, 234, 246, 323, 344],
        "rgbfloat": [255.0, 191.25, 109.65],
        "rgb": [255, 191, 109],
        "hex": "#ffbf6d",
        "index": 46,
    },
    {
        "name": "Cream Yellow",
        "cmyk": [0, 28, 68, 0],
        "combinations": [
            122,
            192,
            215,
            226,
            267,
            278,
            294,
            295,
            300,
            302,
            304,
            311,
            329,
            342,
        ],
        "rgbfloat": [255.0, 183.6, 81.6],
        "rgb": [255, 183, 81],
        "hex": "#ffb751",
        "index": 47,
    },
    {
        "name": "Golden Yellow",
        "cmyk": [2, 42, 74, 0],
        "combinations": [26, 81, 132, 138, 140, 179],
        "rgbfloat": [249.9, 147.9, 66.3],
        "rgb": [249, 147, 66],
        "hex": "#f99342",
        "index": 48,
    },
    {
        "name": "Vinaceous Cinnamon",
        "cmyk": [4, 40, 42, 0],
        "combinations": [203, 205, 213, 256, 260, 279, 299],
        "rgbfloat": [244.79999999999998, 153.0, 147.9],
        "rgb": [244, 153, 147],
        "hex": "#f49993",
        "index": 49,
    },
    {
        "name": "Ochraceous Salmon",
        "cmyk": [15, 38, 55, 0],
        "combinations": [32, 71, 121, 186, 217, 220, 223, 238, 296, 339],
        "rgbfloat": [216.75, 158.1, 114.74999999999999],
        "rgb": [216, 158, 114],
        "hex": "#d89e72",
        "index": 50,
    },
    {
        "name": "Isabella Color",
        "cmyk": [15, 28, 60, 10],
        "combinations": [4, 12, 241, 292],
        "rgbfloat": [195.07500000000002, 165.24, 91.8],
        "rgb": [195, 165, 91],
        "hex": "#c3a55b",
        "index": 51,
    },
    {
        "name": "Maple",
        "cmyk": [5, 26, 56, 20],
        "combinations": [282],
        "rgbfloat": [193.8, 150.96, 89.75999999999999],
        "rgb": [193, 150, 89],
        "hex": "#c19659",
        "index": 52,
    },
    {
        "name": "Olive Buff",
        "cmyk": [16, 6, 42, 12],
        "combinations": [83, 175, 200, 330, 348],
        "rgbfloat": [
            188.49599999999998,
            210.93599999999998,
            130.15200000000002,
        ],
        "rgb": [188, 210, 130],
        "hex": "#bcd282",
        "index": 53,
    },
    {
        "name": "Ecru",
        "cmyk": [20, 25, 40, 6],
        "combinations": [167, 249, 275, 279, 292, 302, 317, 327],
        "rgbfloat": [191.76, 179.77499999999998, 143.82],
        "rgb": [191, 179, 143],
        "hex": "#bfb38f",
        "index": 54,
    },
    {
        "name": "Yellow",
        "cmyk": [0, 0, 100, 0],
        "combinations": [22, 62, 68, 154, 240, 251, 295, 313],
        "rgbfloat": [255.0, 255.0, 0.0],
        "rgb": [255, 255, 0],
        "hex": "#ffff00",
        "index": 55,
    },
    {
        "name": "Lemon Yellow",
        "cmyk": [5, 0, 85, 0],
        "combinations": [
            45,
            123,
            138,
            158,
            168,
            173,
            189,
            210,
            253,
            259,
            289,
            298,
            306,
            317,
            333,
        ],
        "rgbfloat": [242.25, 255.0, 38.25000000000001],
        "rgb": [242, 255, 38],
        "hex": "#f2ff26",
        "index": 56,
    },
    {
        "name": "Apricot Yellow",
        "cmyk": [0, 10, 100, 0],
        "combinations": [107, 129, 163, 198, 213, 247, 265, 284, 305, 319],
        "rgbfloat": [255.0, 229.5, 0.0],
        "rgb": [255, 229, 0],
        "hex": "#ffe500",
        "index": 57,
    },
    {
        "name": "Pyrite Yellow",
        "cmyk": [23, 25, 80, 0],
        "combinations": [239, 250, 255, 287],
        "rgbfloat": [196.35, 191.25, 50.999999999999986],
        "rgb": [196, 191, 50],
        "hex": "#c4bf32",
        "index": 58,
    },
    {
        "name": "Olive Ocher",
        "cmyk": [18, 26, 90, 0],
        "combinations": [66, 148, 149, 156, 157, 249, 278],
        "rgbfloat": [209.10000000000002, 188.7, 25.499999999999993],
        "rgb": [209, 188, 25],
        "hex": "#d1bc19",
        "index": 59,
    },
    {
        "name": "Yellow Ocher",
        "cmyk": [12, 28, 88, 0],
        "combinations": [42, 96, 118, 124, 126, 191, 222, 325],
        "rgbfloat": [224.4, 183.6, 30.599999999999998],
        "rgb": [224, 183, 30],
        "hex": "#e0b71e",
        "index": 60,
    },
    {
        "name": "Orange Yellow",
        "cmyk": [0, 33, 100, 0],
        "combinations": [114, 148, 153, 164, 170, 257, 286, 338],
        "rgbfloat": [255.0, 170.85, 0.0],
        "rgb": [255, 170, 0],
        "hex": "#ffaa00",
        "index": 61,
    },
    {
        "name": "Yellow Orange",
        "cmyk": [0, 45, 100, 0],
        "combinations": [
            22,
            53,
            89,
            151,
            171,
            209,
            222,
            235,
            267,
            288,
            297,
            312,
            319,
            335,
        ],
        "rgbfloat": [255.0, 140.25, 0.0],
        "rgb": [255, 140, 0],
        "hex": "#ff8c00",
        "index": 62,
    },
    {
        "name": "Apricot Orange",
        "cmyk": [0, 55, 75, 0],
        "combinations": [211, 253, 309, 328],
        "rgbfloat": [255.0, 114.74999999999999, 63.75],
        "rgb": [255, 114, 63],
        "hex": "#ff723f",
        "index": 63,
    },
    {
        "name": "Orange",
        "cmyk": [0, 68, 100, 0],
        "combinations": [7, 46, 141, 144, 149, 256, 272],
        "rgbfloat": [255.0, 81.6, 0.0],
        "rgb": [255, 81, 0],
        "hex": "#ff5100",
        "index": 64,
    },
    {
        "name": "Peach Red",
        "cmyk": [0, 80, 90, 0],
        "combinations": [115, 250, 274, 285, 298, 303, 326, 340],
        "rgbfloat": [255.0, 50.999999999999986, 25.499999999999993],
        "rgb": [255, 50, 25],
        "hex": "#ff3219",
        "index": 65,
    },
    {
        "name": "English Red",
        "cmyk": [13, 73, 100, 0],
        "combinations": [1, 131, 190, 308, 339],
        "rgbfloat": [221.85, 68.85000000000001, 0.0],
        "rgb": [221, 68, 0],
        "hex": "#dd4400",
        "index": 66,
    },
    {
        "name": "Cinnamon Rufous",
        "cmyk": [20, 60, 82, 5],
        "combinations": [8, 10, 103, 158, 172, 204, 206],
        "rgbfloat": [193.79999999999998, 96.89999999999999, 43.60500000000001],
        "rgb": [193, 96, 43],
        "hex": "#c1602b",
        "index": 67,
    },
    {
        "name": "Orange Rufous",
        "cmyk": [18, 65, 100, 8],
        "combinations": [91, 102, 222],
        "rgbfloat": [192.37200000000004, 82.11, 0.0],
        "rgb": [192, 82, 0],
        "hex": "#c05200",
        "index": 68,
    },
    {
        "name": "Sulphine Yellow",
        "cmyk": [24, 32, 100, 4],
        "combinations": [36, 65, 142, 160, 252],
        "rgbfloat": [186.048, 166.46399999999997, 0.0],
        "rgb": [186, 166, 0],
        "hex": "#baa600",
        "index": 69,
    },
    {
        "name": "Khaki",
        "cmyk": [24, 45, 100, 6],
        "combinations": [129, 146, 159, 236, 248],
        "rgbfloat": [182.172, 131.83499999999998, 0.0],
        "rgb": [182, 131, 0],
        "hex": "#b68300",
        "index": 70,
    },
    {
        "name": "Citron Yellow",
        "cmyk": [35, 17, 95, 0],
        "combinations": [59, 93, 132, 133, 262],
        "rgbfloat": [165.75, 211.64999999999998, 12.75000000000001],
        "rgb": [165, 211, 12],
        "hex": "#a5d30c",
        "index": 71,
    },
    {
        "name": "Buffy Citrine",
        "cmyk": [42, 40, 82, 8],
        "combinations": [100, 177, 233],
        "rgbfloat": [136.068, 140.76000000000002, 42.228000000000016],
        "rgb": [136, 140, 42],
        "hex": "#888c2a",
        "index": 72,
    },
    {
        "name": "Dark Citrine",
        "cmyk": [38, 34, 67, 20],
        "combinations": [10, 41, 274, 304],
        "rgbfloat": [126.48, 134.64, 67.32],
        "rgb": [126, 134, 67],
        "hex": "#7e8643",
        "index": 73,
    },
    {
        "name": "Light Grayish Olive",
        "cmyk": [43, 36, 62, 19],
        "combinations": [107, 184],
        "rgbfloat": [117.73350000000002, 132.19200000000004, 78.489],
        "rgb": [117, 132, 78],
        "hex": "#75844e",
        "index": 74,
    },
    {
        "name": "Krongbergs Green",
        "cmyk": [48, 35, 70, 12],
        "combinations": [29],
        "rgbfloat": [116.688, 145.86, 67.32000000000001],
        "rgb": [116, 145, 67],
        "hex": "#749143",
        "index": 75,
    },
    {
        "name": "Olive",
        "cmyk": [48, 38, 100, 15],
        "combinations": [96, 201, 254, 258, 277, 310, 334],
        "rgbfloat": [112.71, 134.385, 0.0],
        "rgb": [112, 134, 0],
        "hex": "#708600",
        "index": 76,
    },
    {
        "name": "Orange Citrine",
        "cmyk": [28, 48, 92, 24],
        "combinations": [212, 342],
        "rgbfloat": [139.536, 100.776, 15.503999999999994],
        "rgb": [139, 100, 15],
        "hex": "#8b640f",
        "index": 77,
    },
    {
        "name": "Sudan Brown",
        "cmyk": [25, 60, 65, 19],
        "combinations": [207, 214, 273],
        "rgbfloat": [154.91250000000002, 82.62, 72.2925],
        "rgb": [154, 82, 72],
        "hex": "#9a5248",
        "index": 78,
    },
    {
        "name": "Olive Green",
        "cmyk": [56, 40, 85, 22],
        "combinations": [66, 243, 270, 297],
        "rgbfloat": [87.51599999999999, 119.34, 29.835000000000008],
        "rgb": [87, 119, 29],
        "hex": "#57771d",
        "index": 79,
    },
    {
        "name": "Light Brownish Olive",
        "cmyk": [42, 46, 73, 24],
        "combinations": [199, 318],
        "rgbfloat": [112.40400000000001, 104.65200000000002, 52.32600000000001],
        "rgb": [112, 104, 52],
        "hex": "#706834",
        "index": 80,
    },
    {
        "name": "Deep Grayish Olive",
        "cmyk": [50, 48, 78, 37],
        "combinations": [146, 343],
        "rgbfloat": [80.325, 83.538, 35.342999999999996],
        "rgb": [80, 83, 35],
        "hex": "#505323",
        "index": 81,
    },
    {
        "name": "Pale Raw Umber",
        "cmyk": [46, 63, 87, 32],
        "combinations": [26, 73, 160, 234, 296],
        "rgbfloat": [93.63600000000001, 64.15799999999999, 22.541999999999998],
        "rgb": [93, 64, 22],
        "hex": "#5d4016",
        "index": 82,
    },
    {
        "name": "Sepia",
        "cmyk": [48, 60, 100, 40],
        "combinations": [24, 288],
        "rgbfloat": [79.55999999999999, 61.199999999999996, 0.0],
        "rgb": [79, 61, 0],
        "hex": "#4f3d00",
        "index": 83,
    },
    {
        "name": "Madder Brown",
        "cmyk": [36, 88, 100, 38],
        "combinations": [28, 79, 98, 173, 237, 275, 323],
        "rgbfloat": [101.18400000000001, 18.971999999999998, 0.0],
        "rgb": [101, 18, 0],
        "hex": "#651200",
        "index": 84,
    },
    {
        "name": "Mars Brown Tobacco",
        "cmyk": [39, 76, 100, 47],
        "combinations": [19],
        "rgbfloat": [82.44149999999999, 32.436, 0.0],
        "rgb": [82, 32, 0],
        "hex": "#522000",
        "index": 85,
    },
    {
        "name": "Vandyke Brown",
        "cmyk": [56, 71, 97, 52],
        "combinations": [110, 113, 118, 182, 192],
        "rgbfloat": [53.855999999999995, 35.496, 3.672000000000003],
        "rgb": [53, 35, 3],
        "hex": "#352303",
        "index": 86,
    },
    {
        "name": "Turquoise Green",
        "cmyk": [29, 0, 24, 0],
        "combinations": [
            36,
            74,
            147,
            163,
            173,
            202,
            223,
            230,
            263,
            272,
            285,
            293,
            300,
            305,
            317,
            346,
        ],
        "rgbfloat": [181.04999999999998, 255.0, 193.8],
        "rgb": [181, 255, 193],
        "hex": "#b5ffc1",
        "index": 87,
    },
    {
        "name": "Glaucous Green",
        "cmyk": [30, 9, 24, 0],
        "combinations": [7, 150, 171, 207, 239, 260],
        "rgbfloat": [178.5, 232.05, 193.8],
        "rgb": [178, 232, 193],
        "hex": "#b2e8c1",
        "index": 88,
    },
    {
        "name": "Dark Greenish Glaucous",
        "cmyk": [30, 15, 36, 0],
        "combinations": [264, 311],
        "rgbfloat": [178.5, 216.75, 163.20000000000002],
        "rgb": [178, 216, 163],
        "hex": "#b2d8a3",
        "index": 89,
    },
    {
        "name": "Yellow Green",
        "cmyk": [35, 0, 72, 0],
        "combinations": [111, 141, 276, 326, 334],
        "rgbfloat": [165.75, 255.0, 71.4],
        "rgb": [165, 255, 71],
        "hex": "#a5ff47",
        "index": 90,
    },
    {
        "name": "Light Green Yellow",
        "cmyk": [26, 5, 85, 0],
        "combinations": [61, 289, 291, 311, 346],
        "rgbfloat": [188.7, 242.25, 38.25000000000001],
        "rgb": [188, 242, 38],
        "hex": "#bcf226",
        "index": 91,
    },
    {
        "name": "Night Green",
        "cmyk": [52, 0, 100, 0],
        "combinations": [19, 32, 158, 326],
        "rgbfloat": [122.39999999999999, 255.0, 0.0],
        "rgb": [122, 255, 0],
        "hex": "#7aff00",
        "index": 92,
    },
    {
        "name": "Olive Yellow",
        "cmyk": [40, 30, 80, 0],
        "combinations": [124, 211, 265, 347],
        "rgbfloat": [153.0, 178.5, 50.999999999999986],
        "rgb": [153, 178, 50],
        "hex": "#99b232",
        "index": 93,
    },
    {
        "name": "Artemesia Green",
        "cmyk": [57, 28, 39, 8],
        "combinations": [293, 312],
        "rgbfloat": [100.87800000000001, 168.912, 143.106],
        "rgb": [100, 168, 143],
        "hex": "#64a88f",
        "index": 94,
    },
    {
        "name": "Andover Green",
        "cmyk": [60, 40, 50, 10],
        "combinations": [244, 346],
        "rgbfloat": [91.8, 137.70000000000002, 114.75],
        "rgb": [91, 137, 114],
        "hex": "#5b8972",
        "index": 95,
    },
    {
        "name": "Rainette Green",
        "cmyk": [42, 20, 62, 10],
        "combinations": [105, 200, 219, 283],
        "rgbfloat": [133.11, 183.6, 87.21000000000001],
        "rgb": [133, 183, 87],
        "hex": "#85b757",
        "index": 96,
    },
    {
        "name": "Pistachio Green",
        "cmyk": [64, 29, 56, 6],
        "combinations": [127, 237],
        "rgbfloat": [86.29199999999999, 170.18699999999998, 105.46799999999999],
        "rgb": [86, 170, 105],
        "hex": "#56aa69",
        "index": 97,
    },
    {
        "name": "Sea Green",
        "cmyk": [80, 0, 51, 0],
        "combinations": [17, 21, 58, 86, 133, 250, 260, 284, 291, 340, 347],
        "rgbfloat": [50.999999999999986, 255.0, 124.95],
        "rgb": [50, 255, 124],
        "hex": "#32ff7c",
        "index": 98,
    },
    {
        "name": "Benzol Green",
        "cmyk": [100, 15, 55, 0],
        "combinations": [15, 54, 92, 122, 155, 247, 266, 267, 281, 304, 306],
        "rgbfloat": [0.0, 216.75, 114.74999999999999],
        "rgb": [0, 216, 114],
        "hex": "#00d872",
        "index": 99,
    },
    {
        "name": "Light Porcelain Green",
        "cmyk": [86, 22, 50, 3],
        "combinations": [44, 193, 328],
        "rgbfloat": [34.629000000000005, 192.933, 123.675],
        "rgb": [34, 192, 123],
        "hex": "#22c07b",
        "index": 100,
    },
    {
        "name": "Green",
        "cmyk": [75, 21, 73, 0],
        "combinations": [198, 216, 293],
        "rgbfloat": [63.75, 201.45000000000002, 68.85000000000001],
        "rgb": [63, 201, 68],
        "hex": "#3fc944",
        "index": 101,
    },
    {
        "name": "Dull Viridian Green",
        "cmyk": [90, 20, 80, 0],
        "combinations": [136, 256, 306, 316],
        "rgbfloat": [25.499999999999993, 204.0, 50.999999999999986],
        "rgb": [25, 204, 50],
        "hex": "#19cc32",
        "index": 102,
    },
    {
        "name": "Oil Green",
        "cmyk": [53, 28, 100, 8],
        "combinations": [245, 299, 320],
        "rgbfloat": [110.262, 168.912, 0.0],
        "rgb": [110, 168, 0],
        "hex": "#6ea800",
        "index": 103,
    },
    {
        "name": "Diamine Green",
        "cmyk": [87, 32, 91, 18],
        "combinations": [38, 146, 217, 242, 251, 313],
        "rgbfloat": [27.183, 142.188, 18.818999999999996],
        "rgb": [27, 142, 18],
        "hex": "#1b8e12",
        "index": 104,
    },
    {
        "name": "Cossack Green",
        "cmyk": [76, 32, 91, 18],
        "combinations": [5, 135, 262, 270, 278, 294, 319, 341, 348],
        "rgbfloat": [50.184, 142.188, 18.818999999999996],
        "rgb": [50, 142, 18],
        "hex": "#328e12",
        "index": 105,
    },
    {
        "name": "Lincoln Green",
        "cmyk": [60, 48, 86, 37],
        "combinations": [70, 121, 203, 210, 280, 290],
        "rgbfloat": [64.26, 83.538, 22.491000000000003],
        "rgb": [64, 83, 22],
        "hex": "#405316",
        "index": 106,
    },
    {
        "name": "Blackish Olive",
        "cmyk": [56, 32, 63, 55],
        "combinations": [109, 318, 336],
        "rgbfloat": [50.48999999999999, 78.02999999999999, 42.457499999999996],
        "rgb": [50, 78, 42],
        "hex": "#324e2a",
        "index": 107,
    },
    {
        "name": "Deep Slate Olive",
        "cmyk": [76, 60, 80, 62],
        "combinations": [189, 229, 268, 303, 310, 321, 332, 341, 342, 348],
        "rgbfloat": [23.256, 38.76, 19.379999999999995],
        "rgb": [23, 38, 19],
        "hex": "#172613",
        "index": 108,
    },
    {
        "name": "Nile Blue",
        "cmyk": [25, 0, 10, 0],
        "combinations": [25, 250, 268, 302, 306, 330, 345],
        "rgbfloat": [191.25, 255.0, 229.5],
        "rgb": [191, 255, 229],
        "hex": "#bfffe5",
        "index": 109,
    },
    {
        "name": "Pale King's Blue",
        "cmyk": [33, 4, 7, 0],
        "combinations": [16, 49, 72, 75, 167, 196, 213, 234, 287],
        "rgbfloat": [170.85, 244.79999999999998, 237.14999999999998],
        "rgb": [170, 244, 237],
        "hex": "#aaf4ed",
        "index": 110,
    },
    {
        "name": "Light Glaucous Blue",
        "cmyk": [35, 10, 14, 0],
        "combinations": [54, 93, 119, 152, 178, 204, 227, 320, 339, 341],
        "rgbfloat": [165.75, 229.5, 219.29999999999998],
        "rgb": [165, 229, 219],
        "hex": "#a5e5db",
        "index": 111,
    },
    {
        "name": "Salvia Blue",
        "cmyk": [41, 25, 10, 0],
        "combinations": [
            29,
            129,
            135,
            139,
            142,
            188,
            209,
            212,
            237,
            272,
            294,
            321,
            330,
        ],
        "rgbfloat": [150.45000000000002, 191.25, 229.5],
        "rgb": [150, 191, 229],
        "hex": "#96bfe5",
        "index": 112,
    },
    {
        "name": "Cobalt Green",
        "cmyk": [42, 0, 42, 0],
        "combinations": [
            156,
            188,
            201,
            202,
            230,
            271,
            281,
            282,
            290,
            291,
            308,
            333,
        ],
        "rgbfloat": [147.9, 255.0, 147.9],
        "rgb": [147, 255, 147],
        "hex": "#93ff93",
        "index": 113,
    },
    {
        "name": "Calamine BLue",
        "cmyk": [50, 0, 20, 0],
        "combinations": [20, 41, 65, 159, 176, 255, 261, 287, 291, 300],
        "rgbfloat": [127.5, 255.0, 204.0],
        "rgb": [127, 255, 204],
        "hex": "#7fffcc",
        "index": 114,
    },
    {
        "name": "Venice Green",
        "cmyk": [58, 0, 30, 0],
        "combinations": [78, 128, 138, 189, 283, 345],
        "rgbfloat": [107.10000000000001, 255.0, 178.5],
        "rgb": [107, 255, 178],
        "hex": "#6bffb2",
        "index": 115,
    },
    {
        "name": "Cerulian Blue",
        "cmyk": [84, 26, 32, 0],
        "combinations": [1, 63, 99, 125, 148, 227, 240, 264],
        "rgbfloat": [40.80000000000001, 188.7, 173.39999999999998],
        "rgb": [40, 188, 173],
        "hex": "#28bcad",
        "index": 116,
    },
    {
        "name": "Peacock Blue",
        "cmyk": [100, 19, 43, 0],
        "combinations": [131, 286],
        "rgbfloat": [0.0, 206.55, 145.35000000000002],
        "rgb": [0, 206, 145],
        "hex": "#00ce91",
        "index": 117,
    },
    {
        "name": "Green Blue",
        "cmyk": [82, 24, 40, 3],
        "combinations": [12, 74, 79, 178, 208, 252, 259, 271, 330],
        "rgbfloat": [44.52300000000001, 187.98600000000002, 148.41],
        "rgb": [44, 187, 148],
        "hex": "#2cbb94",
        "index": 118,
    },
    {
        "name": "Olympic Blue",
        "cmyk": [69, 44, 10, 0],
        "combinations": [44, 67, 157, 194, 231, 274, 324],
        "rgbfloat": [79.05000000000001, 142.8, 229.5],
        "rgb": [79, 142, 229],
        "hex": "#4f8ee5",
        "index": 119,
    },
    {
        "name": "Blue",
        "cmyk": [95, 54, 0, 0],
        "combinations": [
            49,
            51,
            88,
            143,
            154,
            186,
            191,
            215,
            257,
            267,
            295,
            333,
        ],
        "rgbfloat": [12.75000000000001, 117.3, 255.0],
        "rgb": [12, 117, 255],
        "hex": "#0c75ff",
        "index": 120,
    },
    {
        "name": "Antwarp Blue",
        "cmyk": [100, 40, 30, 10],
        "combinations": [
            85,
            106,
            114,
            140,
            163,
            172,
            208,
            244,
            258,
            281,
            299,
            302,
            334,
        ],
        "rgbfloat": [0.0, 137.70000000000002, 160.65],
        "rgb": [0, 137, 160],
        "hex": "#0089a0",
        "index": 121,
    },
    {
        "name": "Helvetia Blue",
        "cmyk": [100, 62, 19, 10],
        "combinations": [39, 48, 161, 187, 218, 259, 312, 347],
        "rgbfloat": [0.0, 87.21000000000001, 185.895],
        "rgb": [0, 87, 185],
        "hex": "#0057b9",
        "index": 122,
    },
    {
        "name": "Dark Medici Blue",
        "cmyk": [70, 45, 45, 15],
        "combinations": [160, 224, 241, 249],
        "rgbfloat": [65.025, 119.21249999999999, 119.21249999999999],
        "rgb": [65, 119, 119],
        "hex": "#417777",
        "index": 123,
    },
    {
        "name": "Dusky Green",
        "cmyk": [100, 30, 64, 50],
        "combinations": [94, 219, 225, 278, 284, 318, 332, 338],
        "rgbfloat": [0.0, 89.25, 45.9],
        "rgb": [0, 89, 45],
        "hex": "#00592d",
        "index": 124,
    },
    {
        "name": "Deep Lyons Blue",
        "cmyk": [100, 85, 15, 6],
        "combinations": [22, 38, 101, 126, 179, 199, 236, 247, 314, 344],
        "rgbfloat": [0.0, 35.955000000000005, 203.74499999999998],
        "rgb": [0, 35, 203],
        "hex": "#0023cb",
        "index": 125,
    },
    {
        "name": "Violet Blue",
        "cmyk": [85, 79, 38, 16],
        "combinations": [75, 83, 89, 98, 125, 233, 286, 289, 297, 309, 339],
        "rgbfloat": [32.13, 44.98199999999999, 132.804],
        "rgb": [32, 44, 132],
        "hex": "#202c84",
        "index": 126,
    },
    {
        "name": "Vandar Poel's Blue",
        "cmyk": [100, 73, 43, 10],
        "combinations": [],
        "rgbfloat": [0.0, 61.96500000000001, 130.81500000000003],
        "rgb": [0, 61, 130],
        "hex": "#003d82",
        "index": 127,
    },
    {
        "name": "Dark Tyrian Blue",
        "cmyk": [90, 66, 36, 50],
        "combinations": [2, 60, 67, 119, 141, 245, 279],
        "rgbfloat": [12.749999999999996, 43.349999999999994, 81.60000000000001],
        "rgb": [12, 43, 81],
        "hex": "#0c2b51",
        "index": 128,
    },
    {
        "name": "Dull Violet Black",
        "cmyk": [95, 106, 38, 50],
        "combinations": [95, 106, 145, 265, 277, 289, 295, 331],
        "rgbfloat": [6.375000000000005, -7.650000000000007, 79.05],
        "rgb": [6, -7, 79],
        "hex": "#06-74f",
        "index": 129,
    },
    {
        "name": "Deep Indigo",
        "cmyk": [100, 92, 52, 60],
        "combinations": [6, 28, 139, 155, 182, 211, 232],
        "rgbfloat": [0.0, 8.159999999999997, 48.96],
        "rgb": [0, 8, 48],
        "hex": "#000830",
        "index": 130,
    },
    {
        "name": "Deep Slate Green",
        "cmyk": [80, 50, 60, 70],
        "combinations": [84, 149, 166, 271, 318, 325],
        "rgbfloat": [15.299999999999997, 38.25000000000001, 30.600000000000005],
        "rgb": [15, 38, 30],
        "hex": "#0f261e",
        "index": 131,
    },
    {
        "name": "Grayish Lavender - A",
        "cmyk": [28, 28, 0, 0],
        "combinations": [8, 15, 159, 177, 218, 248, 307],
        "rgbfloat": [183.6, 183.6, 255.0],
        "rgb": [183, 183, 255],
        "hex": "#b7b7ff",
        "index": 132,
    },
    {
        "name": "Grayish Lavender - B",
        "cmyk": [25, 33, 20, 0],
        "combinations": [47, 56, 174, 187, 235, 327, 329, 338],
        "rgbfloat": [191.25, 170.85, 204.0],
        "rgb": [191, 170, 204],
        "hex": "#bfaacc",
        "index": 133,
    },
    {
        "name": "Laelia Pink",
        "cmyk": [20, 48, 18, 0],
        "combinations": [20, 254, 280, 337],
        "rgbfloat": [204.0, 132.6, 209.10000000000002],
        "rgb": [204, 132, 209],
        "hex": "#cc84d1",
        "index": 134,
    },
    {
        "name": "Lilac",
        "cmyk": [28, 54, 8, 0],
        "combinations": [143, 162, 282, 347],
        "rgbfloat": [183.6, 117.3, 234.60000000000002],
        "rgb": [183, 117, 234],
        "hex": "#b775ea",
        "index": 135,
    },
    {
        "name": "Eupatorium Purple",
        "cmyk": [25, 79, 12, 0],
        "combinations": [23, 80, 128, 134, 180, 274],
        "rgbfloat": [191.25, 53.54999999999999, 224.4],
        "rgb": [191, 53, 224],
        "hex": "#bf35e0",
        "index": 136,
    },
    {
        "name": "Light Mauve",
        "cmyk": [43, 62, 5, 0],
        "combinations": [23, 80, 128, 134, 180, 274, 331],
        "rgbfloat": [145.35000000000002, 96.9, 242.25],
        "rgb": [145, 96, 242],
        "hex": "#9160f2",
        "index": 137,
    },
    {
        "name": "Aconite Violet",
        "cmyk": [39, 68, 5, 0],
        "combinations": [43, 64, 90, 187, 220, 257, 269, 301, 307, 324, 344],
        "rgbfloat": [155.54999999999998, 81.6, 242.25],
        "rgb": [155, 81, 242],
        "hex": "#9b51f2",
        "index": 138,
    },
    {
        "name": "Dull Blue Violet",
        "cmyk": [57, 60, 17, 0],
        "combinations": [9, 100],
        "rgbfloat": [109.65, 102.0, 211.64999999999998],
        "rgb": [109, 102, 211],
        "hex": "#6d66d3",
        "index": 139,
    },
    {
        "name": "Dark Soft Violet",
        "cmyk": [70, 68, 13, 0],
        "combinations": [64, 127, 197],
        "rgbfloat": [76.50000000000001, 81.6, 221.85],
        "rgb": [76, 81, 221],
        "hex": "#4c51dd",
        "index": 140,
    },
    {
        "name": "Blue Violet",
        "cmyk": [72, 80, 0, 0],
        "combinations": [116, 175, 196, 322, 345],
        "rgbfloat": [71.4, 50.999999999999986, 255.0],
        "rgb": [71, 50, 255],
        "hex": "#4732ff",
        "index": 141,
    },
    {
        "name": "Purple Drab",
        "cmyk": [38, 65, 49, 26],
        "combinations": [236],
        "rgbfloat": [116.994, 66.045, 96.23700000000001],
        "rgb": [116, 66, 96],
        "hex": "#744260",
        "index": 142,
    },
    {
        "name": "Deep Violet / Plumbeous",
        "cmyk": [61, 52, 43, 7],
        "combinations": [183, 192, 218],
        "rgbfloat": [92.4885, 113.83199999999998, 135.1755],
        "rgb": [92, 113, 135],
        "hex": "#5c7187",
        "index": 143,
    },
    {
        "name": "Veronia Purple",
        "cmyk": [42, 78, 46, 15],
        "combinations": [13, 24, 168, 183],
        "rgbfloat": [125.715, 47.684999999999995, 117.04500000000002],
        "rgb": [125, 47, 117],
        "hex": "#7d2f75",
        "index": 144,
    },
    {
        "name": "Dark Slate Purple",
        "cmyk": [64, 85, 60, 10],
        "combinations": [225, 248],
        "rgbfloat": [82.62, 34.425000000000004, 91.8],
        "rgb": [82, 34, 91],
        "hex": "#52225b",
        "index": 145,
    },
    {
        "name": "Taupe Brown",
        "cmyk": [30, 70, 35, 40],
        "combinations": [57, 123, 174, 224, 275, 280, 288],
        "rgbfloat": [107.1, 45.900000000000006, 99.45],
        "rgb": [107, 45, 99],
        "hex": "#6b2d63",
        "index": 146,
    },
    {
        "name": "Violet Carmine",
        "cmyk": [64, 90, 70, 10],
        "combinations": [337],
        "rgbfloat": [82.62, 22.949999999999996, 68.85000000000001],
        "rgb": [82, 22, 68],
        "hex": "#521644",
        "index": 147,
    },
    {
        "name": "Violet",
        "cmyk": [85, 90, 18, 0],
        "combinations": [
            42,
            56,
            130,
            156,
            164,
            181,
            205,
            214,
            226,
            316,
            331,
            335,
        ],
        "rgbfloat": [38.25000000000001, 25.499999999999993, 209.10000000000002],
        "rgb": [38, 25, 209],
        "hex": "#2619d1",
        "index": 148,
    },
    {
        "name": "Red Violet",
        "cmyk": [76, 100, 25, 15],
        "combinations": [4, 37, 134, 136, 170, 172, 183, 316],
        "rgbfloat": [52.019999999999996, 0.0, 162.5625],
        "rgb": [52, 0, 162],
        "hex": "#3400a2",
        "index": 149,
    },
    {
        "name": "Cotinga Purple",
        "cmyk": [66, 100, 42, 40],
        "combinations": [61, 181, 238, 253, 307, 329, 348],
        "rgbfloat": [52.01999999999999, 0.0, 88.74],
        "rgb": [52, 0, 88],
        "hex": "#340058",
        "index": 150,
    },
    {
        "name": "Dusky Madder Violet",
        "cmyk": [75, 100, 46, 30],
        "combinations": [18, 50, 53, 82, 103, 314],
        "rgbfloat": [44.625, 0.0, 96.39],
        "rgb": [44, 0, 96],
        "hex": "#2c0060",
        "index": 151,
    },
    {
        "name": "White",
        "cmyk": [0, 0, 0, 0],
        "combinations": [55],
        "rgbfloat": [255.0, 255.0, 255.0],
        "rgb": [255, 255, 255],
        "hex": "#ffffff",
        "index": 152,
    },
    {
        "name": "Neutral Gray",
        "cmyk": [29, 18, 20, 0],
        "combinations": [
            34,
            139,
            180,
            195,
            197,
            221,
            228,
            229,
            273,
            303,
            324,
            340,
        ],
        "rgbfloat": [181.04999999999998, 209.10000000000002, 204.0],
        "rgb": [181, 209, 204],
        "hex": "#b5d1cc",
        "index": 153,
    },
    {
        "name": "Mineral Gray",
        "cmyk": [33, 18, 25, 7],
        "combinations": [11, 30],
        "rgbfloat": [
            158.89049999999997,
            194.46300000000002,
            177.86249999999998,
        ],
        "rgb": [158, 194, 177],
        "hex": "#9ec2b1",
        "index": 154,
    },
    {
        "name": "Warm Gray",
        "cmyk": [37, 28, 36, 3],
        "combinations": [69, 76, 81, 143, 169, 238, 259, 261],
        "rgbfloat": [155.8305, 178.09199999999998, 158.304],
        "rgb": [155, 178, 158],
        "hex": "#9bb29e",
        "index": 155,
    },
    {
        "name": "Slate Color",
        "cmyk": [85, 70, 62, 30],
        "combinations": [
            27,
            33,
            57,
            140,
            202,
            243,
            245,
            251,
            253,
            263,
            296,
            329,
            335,
        ],
        "rgbfloat": [26.775000000000002, 53.550000000000004, 67.83],
        "rgb": [26, 53, 67],
        "hex": "#1a3543",
        "index": 156,
    },
    {
        "name": "Black",
        "cmyk": [20, 10, 15, 100],
        "combinations": [
            46,
            52,
            62,
            69,
            112,
            117,
            144,
            190,
            207,
            216,
            221,
            242,
            255,
            256,
            269,
            276,
            288,
            198,
            313,
            323,
            337,
            340,
            344,
        ],
        "rgbfloat": [0.0, 0.0, 0.0],
        "rgb": [0, 0, 0],
        "hex": "#000000",
        "index": 157,
    },
]
COMBINATIONS = {
    "1": [65, 115],
    "2": [127],
    "3": [13, 39],
    "4": [50, 148],
    "5": [104],
    "6": [7, 129],
    "7": [63, 87],
    "8": [66, 131],
    "9": [36, 138],
    "10": [66, 72],
    "11": [41, 153],
    "12": [50, 117],
    "13": [13, 143],
    "14": [9, 40],
    "15": [98, 131],
    "16": [33, 109],
    "17": [12, 97],
    "18": [2, 3, 150],
    "19": [84, 91],
    "20": [113, 133],
    "21": [7, 97],
    "22": [54, 61, 124],
    "23": [45, 135, 136],
    "24": [82, 143],
    "25": [18, 108],
    "26": [47, 81],
    "27": [1, 155],
    "28": [83, 129],
    "29": [74, 111],
    "30": [29, 153],
    "31": [17, 39],
    "32": [49, 91],
    "33": [13, 155],
    "34": [8, 152],
    "35": [4, 28],
    "36": [68, 86],
    "37": [27, 148],
    "38": [103, 124],
    "39": [22, 121],
    "40": [14],
    "41": [72, 113],
    "42": [59, 147],
    "43": [1, 137],
    "44": [99, 118],
    "45": [42, 55],
    "46": [63, 156],
    "47": [18, 132],
    "48": [24, 121],
    "49": [109, 119],
    "50": [41, 150],
    "51": [28, 119],
    "52": [38, 156],
    "53": [61, 150],
    "54": [98, 110],
    "55": [10, 151],
    "56": [132, 147],
    "57": [145, 155],
    "58": [32, 97],
    "59": [8, 70],
    "60": [39, 127],
    "61": [90, 149],
    "62": [54, 156],
    "63": [37, 115],
    "64": [137, 139],
    "65": [68, 113],
    "66": [58, 78],
    "67": [118, 127],
    "68": [4, 54],
    "69": [154, 156],
    "70": [13, 105],
    "71": [29, 49],
    "72": [38, 109],
    "73": [81],
    "74": [86, 117],
    "75": [109, 125],
    "76": [39, 154],
    "77": [12],
    "78": [44, 114],
    "79": [83, 117],
    "80": [38, 135, 136],
    "81": [47, 154],
    "82": [32, 150],
    "83": [52, 125],
    "84": [42, 130],
    "85": [14, 120],
    "86": [13, 97],
    "87": [1],
    "88": [42, 119],
    "89": [61, 125],
    "90": [8, 137],
    "91": [37, 67],
    "92": [5, 98],
    "93": [70, 110],
    "94": [41, 123],
    "95": [32, 128],
    "96": [59, 75],
    "97": [1, 18],
    "98": [83, 125],
    "99": [39, 115],
    "100": [71, 138],
    "101": [124],
    "102": [41, 67],
    "103": [66, 150],
    "104": [28, 38],
    "105": [95],
    "106": [120, 128],
    "107": [56, 73],
    "108": [8, 27],
    "109": [39, 106],
    "110": [31, 85],
    "111": [39, 89],
    "112": [7, 156],
    "113": [42, 85],
    "114": [60, 120],
    "115": [40, 64],
    "116": [140],
    "117": [22, 156],
    "118": [59, 85],
    "119": [110, 127],
    "120": [29],
    "121": [31, 49, 105],
    "122": [22, 46, 98],
    "123": [5, 55, 145],
    "124": [35, 59, 92],
    "125": [2, 3, 115, 125],
    "126": [41, 59, 124],
    "127": [45, 96, 139],
    "128": [1, 114, 135, 136],
    "129": [56, 69, 111],
    "130": [13, 28, 147],
    "131": [13, 65, 116],
    "132": [38, 47, 70],
    "133": [33, 70, 97],
    "134": [8, 135, 136, 148],
    "135": [38, 104, 111],
    "136": [21, 101, 148],
    "137": [18, 45],
    "138": [47, 55, 114],
    "139": [111, 129, 152],
    "140": [47, 120, 155],
    "141": [63, 89, 127],
    "142": [26, 68, 111],
    "143": [119, 134, 154],
    "144": [24, 63, 156],
    "145": [31, 128],
    "146": [69, 80, 103],
    "147": [9, 33, 86],
    "148": [58, 60, 115],
    "149": [58, 63, 130],
    "150": [42, 87],
    "151": [38, 61],
    "152": [18, 32, 110],
    "153": [8, 60],
    "154": [22, 54, 119],
    "155": [15, 98, 129],
    "156": [58, 112, 147],
    "157": [34, 58, 118],
    "158": [55, 66, 91],
    "159": [69, 113, 131],
    "160": [68, 81, 122],
    "161": [31, 121],
    "162": [10, 134],
    "163": [56, 86, 120],
    "164": [17, 60, 147],
    "165": [9, 37],
    "166": [7, 40, 130],
    "167": [53, 109],
    "168": [55, 143],
    "169": [1, 39, 154],
    "170": [24, 60, 148],
    "171": [35, 61, 87],
    "172": [66, 120, 148],
    "173": [55, 83, 86],
    "174": [1, 132, 145],
    "175": [44, 52, 140],
    "176": [0, 42, 113],
    "177": [35, 71, 131],
    "178": [41, 110, 117],
    "179": [17, 47, 124],
    "180": [45, 135, 136, 152],
    "181": [28, 147, 149],
    "182": [13, 85, 129],
    "183": [142, 143, 148],
    "184": [9, 41, 73],
    "185": [4, 18, 39],
    "186": [32, 49, 119],
    "187": [121, 132, 137],
    "188": [111, 112],
    "189": [55, 107, 114],
    "190": [41, 65, 156],
    "191": [4, 59, 119],
    "192": [46, 85, 142],
    "193": [7, 40, 99],
    "194": [15, 42, 118],
    "195": [9, 39, 152],
    "196": [109, 140],
    "197": [8, 139, 152],
    "198": [19, 56, 100, 156],
    "199": [20, 79, 124],
    "200": [28, 52, 95],
    "201": [7, 75, 112],
    "202": [86, 112, 155],
    "203": [39, 48, 105],
    "204": [24, 66, 110],
    "205": [35, 48, 147],
    "206": [1, 66],
    "207": [77, 87, 156],
    "208": [38, 117, 120],
    "209": [41, 61, 111],
    "210": [45, 55, 105],
    "211": [62, 92, 129],
    "212": [29, 76, 111],
    "213": [48, 56, 109],
    "214": [41, 77, 147],
    "215": [46, 119],
    "216": [15, 100, 156],
    "217": [35, 49, 103],
    "218": [121, 131, 142],
    "219": [15, 95, 123],
    "220": [25, 49, 137],
    "221": [28, 152, 156],
    "222": [59, 61, 67],
    "223": [4, 49, 86],
    "224": [9, 122, 145],
    "225": [22, 123, 144],
    "226": [37, 46, 147],
    "227": [0, 110, 115],
    "228": [28, 39, 152],
    "229": [107, 152],
    "230": [7, 86, 112],
    "231": [32, 118],
    "232": [22, 44, 129],
    "233": [28, 71, 125],
    "234": [45, 81, 109],
    "235": [41, 61, 132],
    "236": [69, 124, 141],
    "237": [28, 83, 96, 111],
    "238": [49, 149, 154],
    "239": [4, 57, 87],
    "240": [6, 54, 115],
    "241": [17, 39, 50, 122],
    "242": [8, 19, 103, 156],
    "243": [13, 41, 78, 155],
    "244": [4, 14, 94, 120],
    "245": [28, 102, 127, 155],
    "246": [1, 27, 38, 45],
    "247": [13, 56, 98, 124],
    "248": [8, 69, 131, 144],
    "249": [32, 53, 58, 122],
    "250": [57, 64, 97, 108],
    "251": [30, 54, 103, 155],
    "252": [12, 13, 68, 117],
    "253": [55, 62, 149, 155],
    "254": [1, 38, 75, 133],
    "255": [13, 57, 113, 156],
    "256": [48, 63, 101, 156],
    "257": [16, 60, 119, 137],
    "258": [35, 44, 75, 120],
    "259": [55, 117, 121, 154],
    "260": [10, 48, 87, 97],
    "261": [30, 39, 113, 154],
    "262": [12, 41, 70, 104],
    "263": [19, 44, 86, 155],
    "264": [1, 17, 88, 115],
    "265": [10, 56, 92, 128],
    "266": [16, 41, 98],
    "267": [46, 61, 98, 119],
    "268": [4, 13, 107, 108],
    "269": [13, 35, 137, 156],
    "270": [12, 38, 78, 104],
    "271": [25, 112, 117, 130],
    "272": [39, 63, 86, 111],
    "273": [0, 34, 77, 152],
    "274": [64, 72, 118, 135, 136],
    "275": [18, 53, 83, 145],
    "276": [8, 42, 89, 156],
    "277": [9, 24, 75, 128],
    "278": [46, 58, 104, 123],
    "279": [13, 48, 53, 127],
    "280": [12, 105, 133, 145],
    "281": [39, 98, 112, 120],
    "282": [12, 51, 112, 134],
    "283": [20, 35, 95, 114],
    "284": [11, 56, 97, 123],
    "285": [4, 19, 64, 86],
    "286": [19, 60, 116, 125],
    "287": [8, 57, 109, 113],
    "288": [61, 82, 145, 156],
    "289": [55, 90, 125, 128],
    "290": [37, 39, 105, 112],
    "291": [90, 97, 112, 113],
    "292": [39, 44, 50, 53],
    "293": [13, 86, 93, 100],
    "294": [38, 46, 104, 111],
    "295": [46, 54, 119, 128],
    "296": [38, 49, 81, 155],
    "297": [19, 61, 78, 125],
    "298": [13, 55, 64],
    "299": [23, 48, 102, 120],
    "300": [7, 46, 86, 113],
    "301": [16, 41, 137],
    "302": [46, 53, 108, 120],
    "303": [40, 64, 107, 152],
    "304": [32, 46, 72, 98],
    "305": [44, 56, 86],
    "306": [55, 98, 101, 108],
    "307": [22, 131, 137, 149],
    "308": [2, 3, 21, 65, 112],
    "309": [62, 125],
    "310": [38, 44, 75, 107],
    "311": [29, 46, 88, 90],
    "312": [19, 61, 93, 121],
    "313": [22, 54, 103, 156],
    "314": [8, 32, 124, 150],
    "315": [7, 38],
    "316": [33, 101, 147, 148],
    "317": [43, 53, 55, 86],
    "318": [79, 106, 123, 130],
    "319": [13, 56, 61, 104],
    "320": [5, 38, 102, 110],
    "321": [4, 38, 107, 111],
    "322": [16, 27, 140],
    "323": [45, 83, 156],
    "324": [29, 118, 137, 152],
    "325": [12, 40, 59, 130],
    "326": [38, 64, 89, 91],
    "327": [8, 13, 53, 132],
    "328": [27, 62, 99],
    "329": [46, 132, 149, 155],
    "330": [52, 108, 111, 117],
    "331": [23, 128, 136, 147],
    "332": [5, 21, 107, 123],
    "333": [19, 55, 112, 119],
    "334": [42, 75, 89, 120],
    "335": [33, 61, 147, 155],
    "336": [8, 32, 39, 106],
    "337": [37, 133, 146, 156],
    "338": [60, 123, 132],
    "339": [49, 65, 110, 125],
    "340": [64, 97, 152, 156],
    "341": [7, 104, 107, 110],
    "342": [1, 46, 76, 107],
    "343": [19, 41, 80],
    "344": [45, 124, 137, 156],
    "345": [32, 108, 114, 140],
    "346": [86, 90, 94],
    "347": [92, 97, 121, 134],
    "348": [52, 104, 107, 149],
}


def load_palette() -> Dict[int, Color]:
    # raw = json.loads(Path(path).read_text())
    # return {c["index"]: Color.from_dict(c) for c in raw}

    # instead use COLORS directly
    return {
        c["index"]: Color(
            index=c["index"],
            name=c["name"],
            cmyk=c["cmyk"],
            rgb=c["rgb"],
            hex=c["hex"],
        )
        for c in COLORS
    }


def load_combinations(palette: Dict[int, Color]) -> Dict[int, ColorCombination]:
    # raw = json.loads(Path(path).read_text())
    # combos: Dict[int, ColorCombination] = {}
    # for k, indices in raw.items():
    #    combos[int(k)] = ColorCombination(
    #        cid=int(k),
    #        colors=tuple(palette[i] for i in indices if i in palette),
    #    )
    # Instead use COMBINATIONS directly
    combos: Dict[int, ColorCombination] = {}
    for k, indices in COMBINATIONS.items():
        combos[int(k)] = ColorCombination(
            cid=int(k),
            colors=tuple(palette[i] for i in indices if i in palette),
        )

    return combos
